@@ -4,6 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "testhelpers.h"
 #include "backends/hafasqueryparser.h"
 
 #include <KPublicTransport/Journey>
@@ -14,19 +15,12 @@
 
 #define s(x) QStringLiteral(x)
 
+using namespace Qt::Literals;
 using namespace KPublicTransport;
 
 class HafasQueryParserTest : public QObject
 {
     Q_OBJECT
-private:
-    QByteArray readFile(const char *fn)
-    {
-        QFile f(QString::fromUtf8(fn));
-        f.open(QFile::ReadOnly);
-        return f.readAll();
-    }
-
 private Q_SLOTS:
     void initTestCase()
     {
@@ -39,16 +33,38 @@ private Q_SLOTS:
         QSKIP("not supported on big endian systems yet!", SkipAll);
 #endif
         HafasQueryParser p;
-        const auto res = p.parseQueryJourneyResponse(readFile(SOURCE_DIR "/data/hafas/journey-binary-error.bin.gz"));
+        const auto res = p.parseQueryJourneyResponse(Test::readFile(SOURCE_DIR "/data/hafas/journey-binary-error.bin.gz"));
         QVERIFY(res.empty());
         QCOMPARE(p.error(), Reply::NotFoundError);
     }
 
+    void testParseJourney()
+    {
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN
+        QSKIP("not supported on big endian systems yet!", SkipAll);
+#endif
+
+        QFile f(u"" SOURCE_DIR "/data/hafas/journey-railteam.bin.gz"_s);
+        QVERIFY(f.open(QFile::ReadOnly));
+        const auto data = f.readAll(); // can't use Test::readFile here as that assumes text files!
+
+        HafasQueryParser p;
+        const auto res = p.parseQueryJourneyResponse(data);
+        QVERIFY(!res.empty());
+        QCOMPARE(p.error(), Reply::NoError);
+
+        const auto jsonRes = Journey::toJson(res);
+        const auto ref = QJsonDocument::fromJson(Test::readFile(u"" SOURCE_DIR "/data/hafas/journey-railteam.json"_s)).array();
+
+        QVERIFY(!jsonRes.empty());
+        QVERIFY(Test::compareJson(u"" SOURCE_DIR "/data/hafas/journey-railteam.json"_s, jsonRes, ref));
+    }
+
     void testParseLocationByCoordinateResponse()
     {
         HafasQueryParser p;
         p.setLocationIdentifierTypes(s("testId"));
-        auto res = p.parseQueryLocationResponse(readFile(SOURCE_DIR "/data/hafas/query-location-response.json"));
+        auto res = p.parseQueryLocationResponse(Test::readFile(SOURCE_DIR "/data/hafas/query-location-response.json"));
         QCOMPARE(res.size(), 1);
         QCOMPARE(p.error(), Reply::NoError);
 
@@ -58,7 +74,7 @@ private Q_SLOTS:
         QCOMPARE((int)loc.latitude(), 50);
         QCOMPARE((int)loc.longitude(), 8);
 
-        res = p.parseQueryLocationResponse(readFile(SOURCE_DIR "/data/hafas/query-location-response-sbb-broken-json.json"));
+        res = p.parseQueryLocationResponse(Test::readFile(SOURCE_DIR "/data/hafas/query-location-response-sbb-broken-json.json"));
         QCOMPARE(res.size(), 1);
         QCOMPARE(p.error(), Reply::NoError);
 
