@@ -59,11 +59,7 @@ private Q_SLOTS:
         const auto jsonRes = Location::toJson(res);
 
         const auto ref = QJsonDocument::fromJson(Test::readFile(refFileName)).array();
-        if (jsonRes != ref) {
-            qDebug().noquote() << QJsonDocument(jsonRes).toJson();
-        }
-        QVERIFY(!jsonRes.empty());
-        QCOMPARE(jsonRes, ref);
+        QVERIFY(Test::compareJson(refFileName, jsonRes, ref));
     }
 
     void testParseStopover_data()
@@ -92,11 +88,7 @@ private Q_SLOTS:
         const auto jsonRes = Stopover::toJson(res);
 
         const auto ref = QJsonDocument::fromJson(Test::readFile(refFileName)).array();
-        if (jsonRes != ref) {
-            qDebug().noquote() << QJsonDocument(jsonRes).toJson();
-        }
-        QVERIFY(!jsonRes.empty());
-        QCOMPARE(jsonRes, ref);
+        QVERIFY(Test::compareJson(refFileName, jsonRes, ref));
     }
 
     void testParseJourney_data()
@@ -125,11 +117,7 @@ private Q_SLOTS:
         const auto jsonRes = Journey::toJson(res);
 
         const auto ref = QJsonDocument::fromJson(Test::readFile(refFileName)).array();
-        if (jsonRes != ref) {
-            qDebug().noquote() << QJsonDocument(jsonRes).toJson();
-        }
-        QVERIFY(!jsonRes.empty());
-        QCOMPARE(jsonRes, ref);
+        QVERIFY(Test::compareJson(refFileName, jsonRes, ref));
     }
 
     void testParseError()
