@@ -65,8 +65,9 @@ public:
     ~HafasMgateBackend() override;
 
     void init() override;
-    static inline constexpr const char* type() { return "hafasMgate"; }
+    static constexpr const char* type() { return "hafasMgate"; }
     Capabilities capabilities() const override;
+    [[nodiscard]] Location::Types supportedLocationTypes() const override;
     bool needsLocationQuery(const Location &loc, AbstractBackend::QueryType type) const override;
     bool queryJourney(const JourneyRequest &request, JourneyReply *reply, QNetworkAccessManager *nam) const override;
     bool queryStopover(const StopoverRequest &request, StopoverReply *reply, QNetworkAccessManager *nam) const override;
