@@ -9,8 +9,10 @@
 #include "datatypes_p.h"
 #include "json_p.h"
 #include "notesutil_p.h"
+#include "path.h"
 
 using namespace KPublicTransport;
+using namespace Qt::Literals;
 
 namespace KPublicTransport {
 
@@ -39,6 +41,20 @@ void Equipment::addNote(const QString& note)
     }
 }
 
+QString Equipment::iconName() const
+{
+    switch (d->type) {
+        case Elevator:
+            return PathSection::maneuverIconName(PathSection::Elevator);
+        case Escalator:
+            return PathSection::maneuverIconName(PathSection::Escalator);
+        case Unknown:
+            break;
+    }
+
+    return u"map-symbolic"_s;
+}
+
 QJsonObject Equipment::toJson(const Equipment &equipment)
 {
     return Json::toJson(equipment);
