@@ -5,11 +5,15 @@
 */
 
 #include "vehicle.h"
+
+#include "classutil.h"
 #include "json_p.h"
 #include "datatypes_p.h"
 #include "featureutil_p.h"
 #include "mergeutil_p.h"
 
+#include <KLocalizedString>
+
 #include <QDebug>
 #include <QMetaEnum>
 #include <QVariant>
@@ -60,6 +64,32 @@ KPUBLICTRANSPORT_MAKE_PROPERTY(VehicleSection, QString, platformSectionName, set
 KPUBLICTRANSPORT_MAKE_PROPERTY(VehicleSection, KPublicTransport::Disruption::Effect, disruptionEffect, setDisruptionEffect)
 KPUBLICTRANSPORT_MAKE_PROPERTY(VehicleSection, KPublicTransport::Load::Category, load, setLoad)
 
+QString VehicleSection::typeName() const
+{
+    switch (d->type) {
+        case UnknownType:
+        case Engine:
+        case PowerCar:
+        case ControlCar:
+        case PassengerCar:
+            break;
+        case SleepingCar:
+            return i18nc("train coach type", "Sleeping car");
+        case CouchetteCar:
+            return i18nc("train coach type", "Couchette car");
+        case RestaurantCar:
+            return i18nc("train coach type", "Restaurant car");
+        case CarTransportCar:
+            return i18nc("train coach type", "Car transport car");
+    }
+    return {};
+}
+
+QString VehicleSection::classesName() const
+{
+    return ClassUtil::displayName(d->classes);
+}
+
 const std::vector<KPublicTransport::Feature>& VehicleSection::sectionFeatures() const
 {
     return d->sectionFeatures;
@@ -328,4 +358,35 @@ std::vector<KPublicTransport::Feature> Vehicle::combinedFeatures() const
     return features;
 }
 
+std::vector<KPublicTransport::LoadInfo> Vehicle::aggregatedOccupancy() const
+{
+    std::vector<LoadInfo> l;
+    for (const auto &section : d->sections) {
+        if (section.load() == Load::Category::Unknown) {
+            continue;
+        }
+        LoadInfo o(section.load());
+        if (section.classes() == VehicleSection::FirstClass) {
+            o.setSeatingClass(u"1"_s);
+        } else if (section.classes() == VehicleSection::SecondClass) {
+            o.setSeatingClass(u"2"_s);
+        }
+        auto it = std::ranges::find_if(l, [&o](const auto &info) {
+            return info.seatingClass() == o.seatingClass();
+        });
+        if (it == l.end()) {
+            l.push_back(std::move(o));
+        } else {
+            (*it).setLoad(std::max((*it).load(), o.load()));
+        }
+    }
+
+    std::ranges::sort(l, [](const auto &lhs, const auto &rhs) { return lhs.seatingClass() < rhs.seatingClass(); });
+    if (l.size() > 1 && l[0].seatingClass().isEmpty()) {
+        l.erase(l.begin());
+    }
+
+    return l;
+}
+
 #include "moc_vehicle.cpp"
