@@ -23,6 +23,14 @@ namespace GBFS
         StationInformation,
         StationStatus,
         FreeBikeStatus,
+        Versions,
+        VehicleTypes,
+        GeofencingZones,
+        SystemHours,
+        SystemCalendar,
+        SystemRegions,
+        SystemPricingPlans,
+        SystemAlerts,
         Unknown, // keep last
     };
 
