@@ -18,8 +18,7 @@
 #include <QMetaEnum>
 #include <QSharedData>
 
-#include <unordered_map>
-
+using namespace Qt::Literals;
 using namespace KPublicTransport;
 
 enum { JourneyCacheTimeResolution = 60 }; // in seconds
@@ -33,7 +32,7 @@ public:
     std::vector<RequestContext> contexts;
     QStringList backendIds;
     JourneyRequest::DateTimeMode dateTimeMode = JourneyRequest::Departure;
-    JourneySection::Modes modes = JourneySection::PublicTransport | JourneySection::RentedVehicle;
+    JourneySection::Modes modes = JourneySection::PublicTransport | JourneySection::RentedVehicle | JourneySection::Walking;
     int maximumResults = 12;
     bool downloadAssets = false;
     bool includeIntermediateStops = true;
@@ -41,6 +40,7 @@ public:
 
     std::vector<IndividualTransport> accessModes = { {IndividualTransport::Walk} };
     std::vector<IndividualTransport> egressModes = { {IndividualTransport::Walk} };
+    std::vector<IndividualTransport> individualTransportModes = { {IndividualTransport::Walk} };
     std::vector<Line::Mode> lineModes;
 };
 }
@@ -131,10 +131,11 @@ void JourneyRequest::purgeLoops(const JourneyRequest &baseRequest)
 QJsonObject JourneyRequest::toJson(const KPublicTransport::JourneyRequest &req)
 {
     auto obj = Json::toJson(req);
-    obj.insert(QLatin1String("from"), Location::toJson(req.from()));
-    obj.insert(QLatin1String("to"), Location::toJson(req.to()));
-    obj.insert(QLatin1String("accessModes"), IndividualTransport::toJson(req.accessModes()));
-    obj.insert(QLatin1String("egressModes"), IndividualTransport::toJson(req.egressModes()));
+    obj.insert("from"_L1, Location::toJson(req.from()));
+    obj.insert("to"_L1, Location::toJson(req.to()));
+    obj.insert("accessModes"_L1, IndividualTransport::toJson(req.accessModes()));
+    obj.insert("egressModes"_L1, IndividualTransport::toJson(req.egressModes()));
+    obj.insert("individualTransportModes"_L1, IndividualTransport::toJson(req.individualTransportModes()));
     return obj;
 }
 
@@ -209,6 +210,18 @@ const std::vector<Line::Mode>& JourneyRequest::lineModes() const
     return d->lineModes;
 }
 
+static bool hasTakeBikeMode(const std::vector<IndividualTransport> &modes)
+{
+    return std::any_of(modes.begin(), modes.end(), [](const auto &it) {
+        return it.mode() == IndividualTransport::Bike && it.qualifier() == IndividualTransport::None;
+    });
+}
+
+bool JourneyRequest::requiresBikeTransport() const
+{
+    return hasTakeBikeMode(d->accessModes) && hasTakeBikeMode(d->egressModes);
+}
+
 void JourneyRequest::setLineModes(std::vector<Line::Mode> &&lineModes)
 {
     d.detach();
@@ -231,6 +244,28 @@ void JourneyRequest::setLineModesVariant(const QVariantList &lineModes)
     setLineModes(std::move(l));
 }
 
+const std::vector<IndividualTransport>& JourneyRequest::individualTransportModes() const
+{
+    return d->individualTransportModes;
+}
+
+void JourneyRequest::setIndividualTransportModes(std::vector<IndividualTransport> &&modes)
+{
+    d.detach();
+    d->individualTransportModes = std::move(modes);
+}
+
+QVariantList JourneyRequest::individualTransportModesVariant() const
+{
+    return toVariantList(d->individualTransportModes);
+}
+
+void JourneyRequest::setIndividualTransportModesVariant(const QVariantList &modes)
+{
+    d.detach();
+    d->individualTransportModes = IndividualTransport::fromVariant(modes);
+}
+
 QString JourneyRequest::cacheKey() const
 {
     QCryptographicHash hash(QCryptographicHash::Sha1);
@@ -260,14 +295,13 @@ QString JourneyRequest::cacheKey() const
         hash.addData(QMetaEnum::fromType<Line::Mode>().valueToKey(mode));
     }
 
-    return QString::fromUtf8(hash.result().toHex());
-}
+    hash.addData("IVMODES");
+    for (const auto &it : d->individualTransportModes) {
+        hash.addData(QMetaEnum::fromType<IndividualTransport::Mode>().valueToKey(it.mode()));
+        hash.addData(QMetaEnum::fromType<IndividualTransport::Qualifier>().valueToKey(it.qualifier()));
+    }
 
-static bool hasTakeBikeMode(const std::vector<IndividualTransport> &modes)
-{
-    return std::any_of(modes.begin(), modes.end(), [](const auto &it) {
-        return it.mode() == IndividualTransport::Bike && it.qualifier() == IndividualTransport::None;
-    });
+    return QString::fromUtf8(hash.result().toHex());
 }
 
 void JourneyRequest::validate() const
@@ -287,7 +321,7 @@ void JourneyRequest::validate() const
     const auto hasTakeBikeAccess = hasTakeBikeMode(d->accessModes);
     const auto hasTakeBikeEgress = hasTakeBikeMode(d->egressModes);
     if (hasTakeBikeAccess && !hasTakeBikeEgress) {
-        d->egressModes.push_back({ IndividualTransport::Bike });
+        d->egressModes.emplace_back(IndividualTransport::Bike);
     } else if (!hasTakeBikeAccess && hasTakeBikeEgress) {
         d->egressModes.erase(std::remove_if(d->egressModes.begin(), d->egressModes.end(), [](const auto &it) {
             return it.mode() == IndividualTransport::Bike && it.qualifier() == IndividualTransport::None;
