@@ -58,7 +58,11 @@ public:
     enum Roles {
         JourneyRole = Qt::UserRole,
         ScheduledDepartureTime,
-        ScheduledArrivalTime
+        ScheduledArrivalTime,
+
+        /// Useful for creating sections
+        ScheduledDepartureDate,
+        ScheduledArrivalDate,
     };
     Q_ENUM(Roles)
 
