@@ -31,6 +31,7 @@
 #include <KPublicTransport/Platform>
 #include <KPublicTransport/RentalVehicle>
 #include <KPublicTransport/Reply>
+#include <KPublicTransport/StopInformation>
 #include <KPublicTransport/StopoverQueryModel>
 #include <KPublicTransport/StopoverRequest>
 #include <KPublicTransport/TripRequest>
@@ -267,6 +268,18 @@ struct RentalVehicleForeign {
 };
 FOREIGN_ENUM_GADGET(RentalVehicle)
 
+struct RentalVehicleNetworkForeign {
+    Q_GADGET
+    QML_FOREIGN(KPublicTransport::RentalVehicleNetwork)
+    QML_VALUE_TYPE(rentalVehicleNetwork)
+};
+
+struct RentalVehicleStationForeign {
+    Q_GADGET
+    QML_FOREIGN(KPublicTransport::RentalVehicleStation)
+    QML_VALUE_TYPE(rentalVehicleStation)
+};
+
 struct ReplyForeign {
     Q_GADGET
     QML_FOREIGN(KPublicTransport::Reply)
@@ -281,6 +294,12 @@ struct RouteForeign {
     QML_STRUCTURED_VALUE
 };
 
+struct StopInformationForeign {
+    Q_GADGET
+    QML_FOREIGN(KPublicTransport::StopInformation)
+    QML_VALUE_TYPE(stopInformation)
+};
+
 struct StopoverForeign {
     Q_GADGET
     QML_FOREIGN(KPublicTransport::Stopover)
